package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@(!`0````````````(`/@`!````X"1```````!``````````/#3````
M`````````$``.``)`$``'``;``8````%````0`````````!``$```````$``
M0```````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"0```````.`)````````<`````````!P``````````0`````````!````
M!0````````````````!``````````$```````&3`````````9,``````````
M`"````````$````&````",X````````(SF````````C.8```````H`0`````
M```X%0``````````(````````@````8````PS@```````##.8```````,,Y@
M``````"P`0```````+`!````````"``````````$````!````%0"````````
M5`)```````!4`D```````$0`````````1``````````$`````````%#E=&0$
M````-+H````````TND```````#2Z0```````]`````````#T``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"`````````!2Y71D!`````C.````````",Y@```````(SF``
M`````/@!````````^`$````````!`````````"]L:6(V-"]L9"UL:6YU>"UX
M.#8M-C0N<V\N,@`$````$`````$```!'3E4```````(````&````#P````0`
M```4`````P```$=.50`3C.C5D%!C>#TE\]?K+^C5\-[G)A$```!0````!```
M``@````@$!``!4`$A*H"``&`A@&H0B@`($\@!`NXHCA-NH0&"E````!2````
M5P```%P```!=````9````&8```!H````:@```&T`````````;P```'$```!R
M````<P``````````````>O!*:Z$B"R!&F`7&;L7?'^K3[P[.WD<M:W^:?"[%
MF[8@_^0.?$&.Q;B-\0[59-1\V7%8'.)'Q@&L2^/`\MO3';KCDGS"Y3\L^J%L
M8+,!BV]J"4/6A_F<@6:OS&;%N9Q`0D75[,6)!9`,%.*>YN]?>\G5LG':S>.>
M,V+;[0PZEPNGW:-K?ZF<F^&G`@JCX/M)````````````````````````````
M`````````*8!```2`````````````````````````,X"```2````````````
M`````````````$T#```2`````````````````````````"(#```2````````
M`````````````````$(````2`````````````````````````%0#```2````
M`````````````````````(\````2`````````````````````````-D#```2
M`````````````````````````/T````2`````````````````````````&D#
M```2`````````````````````````/X!```2````````````````````````
M`&X!```2`````````````````````````+H#```2````````````````````
M`````+(#```2`````````````````````````,@````2````````````````
M`````````*8$```2`````````````````````````*$!```2````````````
M`````````````(P#```2`````````````````````````'<#```2````````
M`````````````````(`!```2`````````````````````````#P#```2````
M`````````````````````-(#```2`````````````````````````/8#```2
M`````````````````````````+$````2`````````````````````````$X"
M```2`````````````````````````.H!```2````````````````````````
M`,H!```2`````````````````````````'X#```2````````````````````
M`````!T!```2``````````````````````````L!```2````````````````
M`````````)@"```2`````````````````````````/L"```2````````````
M`````````````"\!```2`````````````````````````#,#```2````````
M`````````````````#4"```2``````````````````````````L#```2````
M`````````````````````"H#```2`````````````````````````(4"```2
M`````````````````````````&(#```2`````````````````````````,D"
M```2`````````````````````````"L$```2````````````````````````
M`)(#```2`````````````````````````"0$```2````````````````````
M`````!P"```2`````````````````````````.D#```2````````````````
M`````````!$````@`````````````````````````%0````2````````````
M`````````````%`!```2`````````````````````````.<"```2````````
M`````````````````)$"```2`````````````````````````-<````2````
M`````````````````````$,"```2`````````````````````````#0````2
M`````````````````````````*L!```2`````````````````````````)D#
M```2`````````````````````````'H"```2````````````````````````
M`%T!```2`````````````````````````%H#```2````````````````````
M`````,("```2`````````````````````````!4$```2````````````````
M`````````/T#```2`````````````````````````%P"```2````````````
M`````````````!T$```2`````````````````````````'`#```2````````
M`````````````````"`````@`````````````````````````$$!```2````
M`````````````````````.(#```2`````````````````````````"P"```2
M`````````````````````````*<#```2`````````````````````````!T#
M```2`````````````````````````-\"```2````````````````````````
M`'@````2`````````````````````````&,````2````````````````````
M`````(T!```2`````````````````````````(4#```2````````````````
M`````````,0#```2`````````````````````````-@!```2````````````
M`````````````.P````2``````````````````````````<$```2````````
M`````````````````&H"```2````8!Y``````````````````($%```1`!@`
MF-)@```````(`````````&\$```1`!@`H-)@```````(`````````*\$```2
M``T`P%E```````!P`````````&D$```2``X`:%M``````````````````-0$
M```2``T`D$M````````E"@```````#@$```2``T`P")````````>`@``````
M`(,$```2``T`0$5````````%`````````#@%```2``T`4$5```````#-`0``
M`````&4%```2``T`,%I```````!``````````#(%```2``L`F!U`````````
M`````````)4%```2``T`P%5```````#T`P```````$X$```0`/'_J-)@````
M`````````````+L$```2``T`($=````````E`````````.X$```1``\`@%M`
M```````$`````````*,"```1`!D`T-)@```````3`````````%H$```0`/'_
M0.-@`````````````````#`%```2``T``$1````````M`````````$4%```2
M``T`@$I````````'`0```````%<%```2``T``$I```````!(`````````.$$
M```0`!@`@-)@`````````````````*`````2````L"%`````````````````
M`,@$```2``T`4$=```````#:`````````#T$```1`!D`P-)@```````(````
M`````$<$```0`/'_J-)@`````````````````#X$```A`!D`P-)@```````(
M`````````%\$```2``T`(%M````````"`````````'0$```1``\`0%Y`````
M``#J6P```````+<!```2`````"%``````````````````!,%```2``T`D%I`
M``````")`````````.<$```2``T`X"1``````````````````.,$```@`!@`
M@-)@`````````````````#\$```A`!D`P-)@```````(`````````)0$```2
M``T`4$I````````D`````````/T$```2``T`@$1```````"V`````````",%
M```2``T`,$A```````#+`0````````!L:6)P97)L+G-O+C4N,3(`7U]G;6]N
M7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!097)L7W-Y<U]T97)M`%!E
M<FQ?27-T871B=69?<'1R`%!E<FQ?<WES7VEN:70S`%!E<FQ?265X:71?9FQA
M9W-?<'1R`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%])8V]M<&-V7W!T
M<@!097)L7V%T9F]R:U]L;V-K`%!E<FQ?26-U<G-T86-K:6YF;U]P='(`<&5R
M;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%])<&%R<V5R
M7W!T<@!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?271O
M<%]E;G9?<'1R`%!E<FQ?271A:6YT961?<'1R`%!E<FQ?<W9?<V5T<'9N`%!E
M<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!E<FQ?26EN7V5V86Q?<'1R
M`%!E<FQ?26]P7W!T<@!097)L7TEE=F%L7W)O;W1?<'1R`'!E<FQ?9G)E90!0
M97)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!0
M97)L7T=T:')?:V5Y7W!T<@!097)L7T=D;U]U;F1U;7!?<'1R`%!E<FQ?27!E
M<FQ?9&5S=')U8W1?;&5V96Q?<'1R`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U
M;@!097)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L
M7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F
M97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E
M860N<V\N,`!O<&5N-C0`<F5A9`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`
M<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!L:6)C+G-O+C8`7U]R96=I<W1E
M<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?<W1A
M8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I
M9`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`;65M8W!Y`%]?
M<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!?7V-T
M>7!E7V)?;&]C`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK
M`'-T<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S
M<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]E9&%T80!?
M7V)S<U]S=&%R=`!?96YD`%]?;&EB8U]C<W5?9FEN:0!N86UE7VQO861?;7E?
M<&%R7W!L`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T
M<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A
M<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U
M<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!P87)?:6YI=%]E;G8`
M>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N
M=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`<VEZ95]L;V%D
M7VUY7W!A<E]P;`!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXR+C4`
M1TQ)0D-?,BXS`$=,24)#7S(N,RXT`$=,24)#7S(N,RXR`$=,24)#7S(N-```
M```"``,``@`"`````@````(````"```````"``(````"`````@`"````!``"
M``(````````````"``````````,````"````!0`"`````@`#``(``@`"````
M!@`````````#``(````````````&```````"``,``@`"`````@`"```````"
M`````@`"``,``````````@`'```````&`````0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!`````0`!``$``0`!`````0`"``$``@`!``$````!``$``0`"
M``$``0`!```````!``$`L@(``!`````@````=1II"0```P"K!0````````$`
M!0`!`P``$``````````3:6D-```'`+<%```0````=!EI"0``!@#!!0``$```
M`'(9:0D```4`S04``!`````4:6D-```$`-D%```0````=1II"0```@"K!0``
M`````.#/8```````!@```"X``````````````,#28```````!0```&<`````
M`````````-#28```````!0```%\```````````````#08```````!P````$`
M``````````````C08```````!P````(``````````````!#08```````!P``
M``,``````````````!C08```````!P````0``````````````"#08```````
M!P````4``````````````"C08```````!P````8``````````````##08```
M````!P````<``````````````#C08```````!P````@``````````````$#0
M8```````!P````D``````````````$C08```````!P````H`````````````
M`%#08```````!P```%```````````````%C08```````!P````L`````````
M`````&#08```````!P````P``````````````&C08```````!P````T`````
M`````````'#08```````!P````X``````````````'C08```````!P````\`
M`````````````(#08```````!P```!```````````````(C08```````!P``
M`!$``````````````)#08```````!P```!(``````````````)C08```````
M!P```!,``````````````*#08```````!P```!0``````````````*C08```
M````!P```!4``````````````+#08```````!P```!8``````````````+C0
M8```````!P```!<``````````````,#08```````!P```!@`````````````
M`,C08```````!P```!D``````````````-#08```````!P```!H`````````
M`````-C08```````!P```!L``````````````.#08```````!P```!P`````
M`````````.C08```````!P```!T``````````````/#08```````!P```!X`
M`````````````/C08```````!P```!\```````````````#18```````!P``
M`"````````````````C18```````!P```"$``````````````!#18```````
M!P```"(``````````````!C18```````!P```",``````````````"#18```
M````!P```"0``````````````"C18```````!P```"4``````````````##1
M8```````!P```"8``````````````#C18```````!P```"<`````````````
M`$#18```````!P```"@``````````````$C18```````!P```"D`````````
M`````%#18```````!P```"H``````````````%C18```````!P```"L`````
M`````````&#18```````!P```"P``````````````&C18```````!P```"T`
M`````````````'#18```````!P```"\``````````````'C18```````!P``
M`#```````````````(#18```````!P```#$``````````````(C18```````
M!P```#(``````````````)#18```````!P```#,``````````````)C18```
M````!P```#0``````````````*#18```````!P```&P``````````````*C1
M8```````!P```#4``````````````+#18```````!P```#8`````````````
M`+C18```````!P```#<``````````````,#18```````!P```#@`````````
M`````,C18```````!P```#D``````````````-#18```````!P```#H`````
M`````````-C18```````!P```#L``````````````.#18```````!P```#P`
M`````````````.C18```````!P```#T``````````````/#18```````!P``
M`#X``````````````/C18```````!P```&4```````````````#28```````
M!P```#\```````````````C28```````!P```$```````````````!#28```
M````!P```$(``````````````!C28```````!P```$,``````````````"#2
M8```````!P```$0``````````````"C28```````!P```$4`````````````
M`##28```````!P```$8``````````````#C28```````!P```$<`````````
M`````$#28```````!P```$@``````````````$C28```````!P```$D`````
M`````````%#28```````!P```$H``````````````%C28```````!P```$L`
M`````````````&#28```````!P```$P``````````````&C28```````!P``
M`$T``````````````'#28```````!P```$X``````````````'C28```````
M!P```$\``````````````$B#[`CH:P<``.CZ!P``Z(4]``!(@\0(P_\U.K(@
M`/\E/+(@``\?0`#_)3JR(`!H`````.G@_____R4RLB``:`$```#IT/____\E
M*K(@`&@"````Z<#_____)2*R(`!H`P```.FP_____R4:LB``:`0```#IH/__
M__\E$K(@`&@%````Z9#_____)0JR(`!H!@```.F`_____R4"LB``:`<```#I
M</____\E^K$@`&@(````Z6#_____)?*Q(`!H"0```.E0_____R7JL2``:`H`
M``#I0/____\EXK$@`&@+````Z3#_____)=JQ(`!H#````.D@_____R72L2``
M:`T```#I$/____\ERK$@`&@.````Z0#_____)<*Q(`!H#P```.GP_O___R6Z
ML2``:!````#IX/[___\ELK$@`&@1````Z=#^____):JQ(`!H$@```.G`_O__
M_R6BL2``:!,```#IL/[___\EFK$@`&@4````Z:#^____)9*Q(`!H%0```.F0
M_O___R6*L2``:!8```#I@/[___\E@K$@`&@7````Z7#^____)7JQ(`!H&```
M`.E@_O___R5RL2``:!D```#I4/[___\E:K$@`&@:````Z4#^____)6*Q(`!H
M&P```.DP_O___R5:L2``:!P```#I(/[___\E4K$@`&@=````Z1#^____)4JQ
M(`!H'@```.D`_O___R5"L2``:!\```#I\/W___\E.K$@`&@@````Z>#]____
M)3*Q(`!H(0```.G0_?___R4JL2``:"(```#IP/W___\E(K$@`&@C````Z;#]
M____)1JQ(`!H)````.F@_?___R42L2``:"4```#ID/W___\E"K$@`&@F````
MZ8#]____)0*Q(`!H)P```.EP_?___R7ZL"``:"@```#I8/W___\E\K`@`&@I
M````Z5#]____)>JP(`!H*@```.E`_?___R7BL"``:"L```#I,/W___\EVK`@
M`&@L````Z2#]____)=*P(`!H+0```.D0_?___R7*L"``:"X```#I`/W___\E
MPK`@`&@O````Z?#\____);JP(`!H,````.G@_/___R6RL"``:#$```#IT/S_
M__\EJK`@`&@R````Z<#\____):*P(`!H,P```.FP_/___R6:L"``:#0```#I
MH/S___\EDK`@`&@U````Z9#\____)8JP(`!H-@```.F`_/___R6"L"``:#<`
M``#I</S___\E>K`@`&@X````Z6#\____)7*P(`!H.0```.E0_/___R5JL"``
M:#H```#I0/S___\E8K`@`&@[````Z3#\____)5JP(`!H/````.D@_/___R52
ML"``:#T```#I$/S___\E2K`@`&@^````Z0#\____)4*P(`!H/P```.GP^___
M_R4ZL"``:$````#IX/O___\E,K`@`&A!````Z=#[____)2JP(`!H0@```.G`
M^____R4BL"``:$,```#IL/O___\E&K`@`&A$````Z:#[____)1*P(`!H10``
M`.F0^____R4*L"``:$8```#I@/O___\E`K`@`&A'````Z7#[____)?JO(`!H
M2````.E@^____R7RKR``:$D```#I4/O___\EZJ\@`&A*````Z4#[____)>*O
M(`!H2P```.DP^____R7:KR``:$P```#I(/O___\ETJ\@`&A-````Z1#[____
M)<JO(`!H3@```.D`^____R7"KR``:$\```#I\/K__U-(@^P@B7PD'$B)="00
M2(U\)!Q(B50D"$B-="002(U4)`CHN?W__[H`(4``O[`A0`!(B=;H=S<``#'_
MZ&#\__^`.`!U-NBF_/__2(7`2(D%),`@``^$J0$``$B)Q^B.^___,?_H9___
M_XLXZ)#]__](B<?H./O__\8``#'_Z$[___^+..AW_?__2(G'Z/_^__^`"`(Q
M_^@U____BSCH7OW__TB)Q^CF_O__@`@!BWPD'(/'!4AC_TB%_P^("P$``/)(
M#RK'\@]8!8LZ``!F#RX%BSH```^',@$``$C!YP/H?/S__TB+?"002(D%<+\@
M`,<%;K\@``0```!(BQ=(QT`(9EU``$C'0!!`7D``2,=`&&E=0`!(B1"+5"0<
M@_H!?B*-2OY,C03-"````#')9I!(BW0/"$B)=`@@2(/!"$PYP77MC4H$2(L]
M*[\@`(/"`T4QP+XP1$``2&/)2,=$R/@`````2(G!Z!3]__^%P(G#=#9(BSW_
MOB``Z!+[__\QP+\M7$``Z!88``!(A<!T*4B+/>*^(`#H=?K__^BP_/__2(/$
M((G86\-(BSW)OB``Z(S]__^)P^NZ2(L]L;X@`$B%_W0DZ#<U``#KQ$B)^$B)
M^DC1Z(/B`4@)T/)(#RK`\@]8P.G=_O__O^);0`#HKA<``$B%P$B)QTB)!7&^
M(`!TCNO!OP$```#H4_W__[[0TF``O]U;0``QP.@"_/__D)`Q[4F)T5Y(B>)(
M@^3P4%1)Q\`@6T``2,?!D%I``$C'Q\`B0`#H1_O___20D$B#[`A(BP7)JB``
M2(7`=`+_T$B#Q`C#D)"0D)"0D)"0D)"0D%5(B>532(/L"(`]J*T@``!U2[L@
MSF``2(L%HJT@`$B!ZQC.8`!(P?L#2(/K`4@YV',D9@\?1```2(/``4B)!7VM
M(`#_%,48SF``2(L%;ZT@`$@YV'+BQ@5;K2```4B#Q`A;7<-F9F8N#Q^$````
M``!(@SV`J"```%5(B>5T$K@`````2(7`=`A=ORC.8`#_X%W#D)"0D)"0D)"0
MD)"0D)!!5TR-1S@QR4%6055!5%532('L"`(``&8/'X0``````$F+%`A(B=!(
MB=9(P>`(2,'F&(/F_R4``/\`2`GP2(G62,'N"('F`/\``$@)\$B)UDC![AB!
MYO\```!("?!(B=9(P>X@2(E$3(A(B?!(P>882,'@"(/F_R4``/\`2`GP2(G6
M2,'J.$C![BB!Y@#_``!("?!("=!(B41,D$B#P0A(@_E`#X5W____2(U4)(A(
MC;0D\`$``$B#PFAF#Q]$``!(BT+82#,"2#-"J$@S0IA(B<%(`<!(P>D?2`G!
M@^'_2(E*&$B#P@A(.?)UU$R+!TB+7R!,BT\(3(M7$$R+7QA(B=I,B<!(`U0D
MB$R)P4C!Z!M(P>$%3(G>2`-T))!("<A,B<&#X/](]]%(C:P"F7F"6DR)R$R)
MTDCWT$PARDPAT4PAV$@)T$R)R@'%3(G(2,'B'DC!Z`))B>U("="#X/](B<),
M(<)("<I(B>E,C:06F7F"6DB)ZDC!X05(P>H;3(G62`-T))A("<I,B<%!`=1,
MB<)(P>D"2,'B'D@)T4B)ZH/A_TCWTDDAS4@APDP)ZDV)Y4B-M!:9>8):3(GB
M2<'E!4C!ZAM,">I-B>4!UDB)ZDC!Z@)(P>4>2`-$)*!(">I,B>6#XO](]]5)
M(=5((<U(`TPDJ$P)[4F)]4B-K"B9>8):2(GP2<'E!4C!Z!M,">A)B?4!Q4R)
MX$G!Y!Y(P>@"3`G@28GT@^#_2??422'%22'42`-4)+!-">Q)B>U.C:0AF7F"
M6DB)Z4G!Y05(P>D;3`GI28GM00',2(GQ2,'F'DC!Z0)("?%(B>Z#X?](]]9)
M(<U((<9,">Y-B>5(C;0RF7F"6DR)XDC!ZAM)P>4%2`-$)+A,">I-B>4!UDB)
MZDC!Y1Y(P>H"2`GJ3(GE@^+_2/?522'52"'-2`-,),!,">U)B?5(C:PHF7F"
M6DB)\$G!Y05(P>@;3`GH28GU`<5,B>!)P>0>2,'H`DP)X$F)](/@_TGWU$DA
MQ4DAU$@#5"3(30GL28GM3HVD(9EY@EI(B>E)P>4%2,'I&TP)Z4F)[4$!S$B)
M\4C!YAY(P>D"2`GQ2(GN@^'_2/?62"'&22'-2`-$)-!,">Y-B>5(C;0RF7F"
M6DR)XDG!Y05(P>H;3`GJ38GE`=9(B>I(P>4>2,'J`D@)ZDR)Y8/B_TCWU4DA
MU4@AS4@#3"383`GM28GU2(VL*)EY@EI(B?!)P>4%2,'H&TP)Z$F)]0'%3(G@
M2<'D'DC!Z`),">!)B?2#X/])]]1)(<5)(=1-">Q)B>U.C:0AF7F"6DB)Z4G!
MY05(P>D;3`GI28GM00',2(GQ2,'F'DC!Z0)("?%(B>Z#X?](`U0DX$CWUDDA
MS4@AQD@#1"3H3`GN38GE2<'E!4B-M#*9>8):3(GB2,'J&TP)ZDV)Y0'62(GJ
M2,'E'DC!Z@)(">I,B>6#XO](]]5)(=5((<U(`TPD\$P)[4F)]4B-K"B9>8):
M2(GP2<'E!4C!Z!M,">A)B?4!Q4R)X$G!Y!Y(P>@"3`G@28GT@^#_2??422'%
M22'430GL28GM3HVD(9EY@EI(B>E)P>4%2,'I&TP)Z4F)[4$!S$B)\4C!Z0)(
MP>8>2`-4)/A("?%(B>Z#X?](]]9)(<U((<9(`P0D3`GN38GE2(VT,IEY@EI,
MB>))P>4%2,'J&TP)ZDV)Y0'62(GJ2,'E'DC!Z@)(">I,B>6#XO](]]5)(=5(
M(<U(`TPD"$P)[4F)]4B-K"B9>8):2(GP2<'E!4C!Z!M,">A)B?4!Q4R)X$G!
MY!Y(P>@"3`G@28GT@^#_2??422'%22'430GL28GM3HVD(9EY@EI(B>E(P>D;
M2<'E!4@#5"003`GI28GM00',2(GQ2,'F'DC!Z0)("?%(B>Z#X?](]]9)(<U(
M(<9(`T0D&$P)[DV)Y4B-M#*9>8):3(GB2<'E!4C!ZAM,">I-B>4!UDB)ZDC!
MY1Y(P>H"2`GJ3(GE@^+_2/?522'52"'-2`-,)"!,">U)B?5(C:PHF7F"6DB)
M\$G!Y05(P>@;3`GH28GU`<5,B>!)P>0>2,'H`DP)X$F)](/@_TGWU$DAU$DA
MQ4@#5"0H30GL3HVL(9EY@EI(B>E)B>Q)P>0%2,'I&TP)X4$!S4B)\4C!YAY(
MP>D"2`GQ@^'_2(G.2#'&2`-$)#!(,>Y,C:0RH>O9;DR)ZDR)[DC!Y@5(P>H;
M2`GR00'42(GJ2,'E'DC!Z@)(">J#XO](B=9(,<Y(`TPD.$PQ[DB-K#"AZ]EN
M3(G@3(GF2,'F!4C!Z!M("?`!Q4R)Z$G!Y1Y(P>@"3`GH28GM@^#_2(G&2#'6
M2<'E!4@#5"1`3#'F2(VT,:'KV6Y(B>E(P>D;3`GI`<Y,B>%)P>0>2,'I`DF)
M]4P)X4G!Y06#X?])B<Q),<1(`T0D2$DQ[$Z-I"*AZ]EN2(GR2,'J&TP)ZD$!
MU$B)ZDC!Y1Y(P>H"38GE2`GJ2<'E!8/B_TB)U4@QS4@#3"102#'U2(VL**'K
MV6Y,B>!(P>@;3`GH`<5(B?!(P>8>2,'H`DF)[4@)\(/@_TB)QD@QUDG!Y05(
M`U0D6$PQYDB-M#&AZ]EN2(GI2,'I&TP)Z0'.3(GA2<'D'DC!Z0))B?5,">%)
MP>4%@^'_28G,23'$2`-$)&!),>Q.C:0BH>O9;DB)\DC!ZAM,">I!`=1(B>I(
MP>4>2,'J`DV)Y4@)ZDG!Y06#XO](B=5(,<U(`TPD:$@Q]4B-K"BAZ]EN3(G@
M2,'H&TP)Z`'%2(GP2,'F'DC!Z`))B>U("?"#X/](B<9(,=9)P>4%2`-4)'!,
M,>9(C;0QH>O9;DB)Z4C!Z1M,">D!SDR)X4G!Y!Y(P>D"28GU3`GA2<'E!8/A
M_TF)S$DQQ$@#1"1X23'L3HVD(J'KV6Y(B?)(P>H;3`GJ00'42(GJ2,'E'DC!
MZ@)-B>5(">I)P>4%@^+_2(G52#'-2`.,)(````!(,?5(C:PHH>O9;DR)X$C!
MZ!M,">@!Q4B)\$C!YAY(P>@"28GM2`GP@^#_2(G&2#'62<'E!4@#E"2(````
M3#'F2(VT,:'KV6Y(B>E(P>D;3`GI`<Y,B>%)P>0>2,'I`DF)]4P)X4G!Y06#
MX?])B<Q),<1(`X0DD````$DQ[$Z-I"*AZ]EN2(GR2,'J&TP)ZD$!U$B)ZDC!
MY1Y(P>H"38GE2`GJ2<'E!8/B_TB)U4@QS4@#C"28````2#'U2(VL**'KV6Y,
MB>!(P>@;3`GH`<5(B?!(P>8>2,'H`DF)[4@)\(/@_TB)QD@QUDG!Y05(`Y0D
MH````$PQYDB-M#&AZ]EN2(GI2,'I&TP)Z0'.3(GA2<'D'DC!Z0))B?5,">%)
MP>4%@^'_28G,23'$2`.$)*@```!),>Q.C:0BH>O9;DB)\DC!ZAM,">I!`=1(
MB>I(P>4>2,'J`DV)Y4@)ZDG!Y06#XO](B=5(,<U(`XPDL````$@Q]4B-K"BA
MZ]EN3(G@2,'H&TP)Z`'%2(GP2,'F'DC!Z`)("?"#X/](B<9(,=9(`Y0DN```
M`$PQYDR-K#&AZ]EN2(GI2(GN2,'F!4C!Z1M("?%,B>9)P>0>2,'N`D$!S4P)
MYH/F_TB)\4@QP4@#A"3`````2#'I3(VD"J'KV6Y,B>I,B>E(P>$%2,'J&T@)
MRDB)Z4C!Y1Y(P>D"00'42`GI@^'_2(G*2#'R3#'J2(VL$*'KV6Y,B>!,B>)(
MP>(%2,'H&T@)T$R)ZDG!Y1X!Q4C!Z@*XW+P;CTP)ZDF)Q4P#K"3(````@^+_
M28G63`'N28G522'.20G-32'E30GU28GN20'U2(GN2<'F!4C![AM,"?9!`?5,
MB>9)P>0>2,'N`DP)YDF)Q$P#I"30````@^;_28GV22'63`'A28GT20G422'L
M30GT38GN20',3(GI2<'F!4C!Z1M,"?%!`<Q(B>E(P>4>2,'I`D@)Z4B)Q4@#
MK"38````@^'_28G.2`'J2(G-2`GU3"'M22'V3`GU38GF2`'53(GB2<'F!4C!
MZAM,"?(!U4R)ZDG!Y1Y(P>H"3`GJ28G%3`.L).````"#XO])B=9)(<Y,`>Y)
MB=5)"<U-(>5-"?5)B>Y)`?5(B>Y)P>8%2,'N&TP)]D$!]4R)YDG!Y!Y(P>X"
M3`GF28G$3`.D).@```"#YO])B?9)(=9,`>%)B?1)"=1)(>Q-"?1-B>Y)`<Q,
MB>E(P>D;2<'F!4P)\4$!S$B)Z4C!Y1Y(P>D"2`GI2(G%2`.L)/````"#X?])
MB<Y)(?9(`>I(B<U("?5,(>U,"?5-B>9(`=5,B>))P>8%2,'J&TP)\@'53(GJ
M2<'E'DC!Z@),">I)B<5,`ZPD^````(/B_TF)UDDASDP![DF)U4D)S4TAY4T)
M]4F)[DD!]4B)[DG!Y@5(P>X;3`GV00'U3(GF2<'D'DC![@),">9)B<1,`Z0D
M``$``(/F_TF)]DDAUDP!X4F)]$D)U$DA[$T)]$V)[DD!S$R)Z4G!Y@5(P>D;
M3`GQ00',2(GI2,'E'DC!Z0)(">E(B<5(`ZPD"`$``(/A_TF)SDDA]D@!ZDB)
MS4@)]4PA[4P)]4V)YD@!U4R)XDG!Y@5(P>H;3`GR`=5,B>I)P>4>2,'J`DP)
MZDF)Q4P#K"00`0``@^+_28G622'.3`'N28G520G-32'E30GU28GN20'U2(GN
M2<'F!4C![AM,"?9!`?5,B>9)P>0>2,'N`DP)YDF)Q$P#I"08`0``@^;_28GV
M22'63`'A28GT20G422'L30GT38GN20',3(GI2<'F!4C!Z1M,"?%!`<Q(B>E(
MP>4>2,'I`D@)Z4B)Q4@#K"0@`0``@^'_28G.2`'J2(G-22'V2`GU3"'M3`GU
M38GF2`'53(GB2<'F!4C!ZAM,"?(!U4R)ZDG!Y1Y(P>H"3`GJ28G%3`.L)"@!
M``"#XO])B=9)(<Y,`>Y)B=5)"<U-(>5-"?5)B>Y)`?5(B>Y)P>8%2,'N&TP)
M]D$!]4R)YDG!Y!Y(P>X"3`GF28G$3`.D)#`!``"#YO])B?9,`>%)B?1)"=1)
M(>Q)(=9-"?1-B>Y)`<Q,B>E)P>8%2,'I&TP)\4$!S$B)Z4C!Y1Y(P>D"2`GI
M2(G%2`.L)#@!``"#X?])B<Y)(?9(`>I(B<U("?5,(>U,"?5-B>9(`=5,B>))
MP>8%2,'J&TP)\@'53(GJ2<'E'DC!Z@),">I)B<5,`ZPD0`$``(/B_TF)UDDA
MSDP![DF)U4D)S4TAY4T)]4F)[DD!]4B)[DC![AM)P>8%3`GV00'U3(GF2<'D
M'DC![@),">9)B<1,`Z0D2`$``(/F_TF)]DDAUDP!X4F)]$D)U$DA[$T)]$V)
M[DD!S$R)Z4G!Y@5(P>D;3`GQ00',2(GI2,'E'DC!Z0)(">E(B<5(`ZPD4`$`
M`(/A_TF)SDDA]D@!ZDB)S4@)]4PA[4P)]4V)YD@!U4R)XDG!Y@5(P>H;3`GR
M`=5,B>I)P>4>2,'J`DP)ZDF)Q4P#K"18`0``@^+_2`.$)&`!``!)B=9)(<Y,
M`>Y)B=5)"<U(`<%-(>5-"?5)B>Y)`?5(B>Y)P>8%2,'N&TP)]D$!]4R)YDG!
MY!Y(P>X"3`GF@^;_2(GP28GT2`G022'42"'H3`G@28GL2,'E'DR--`%,B>A,
MB>E(P>$%2,'H&TG![`)("<A)">Q!`<:XUL%BRD&#Y/](B<%(`XPD:`$``$R)
M]4C!Y05(`<I,B>%(,?%,,>E(`=%,B?)(P>H;2`GJ3(GM2<'E'D2-/`I(B<)(
M`Y0D<`$``$C![0),">U,B?F#Y?](P>$%2`'62(GJ3#'B3#'R3(TL%DR)^DC!
MZAM("<I,B?%)P>8>00'52(G"2`.4)'@!``!(P>D"3(GN3`GQ2,'F!8/A_TD!
MU$B)RD@QZDPQ^DD!U$R)ZDC!ZAM("?)(B<9!`=1(`[0D@`$``$R)^DC!Z@))
MP><>38GF3`GZ2<'F!8/B_T@!]4B)UD@QSDPQ[D@!]4R)YDC![AM,"?8!]4R)
M[DG!Y1Y(P>X"28GN3`GN28G%3`.L)(@!``"#YO])P>8%3`'I28GU23'533'E
M20'-2(GI2,'I&TP)\4$!S4R)X4G!Y!Y(P>D"38GN3`GA28G$3`.D))`!``"#
MX?],`>))B<Q),?1)P>8%23'L20'43(GJ2,'J&TP)\D$!U$B)ZDC!Y1Y(P>H"
M38GF2`GJ2(G%2`.L))@!``"#XO])P>8%2`'N2(G52#'-3#'M2`'U3(GF2,'N
M&TP)]@'U3(GN2<'E'DC![@))B>Y,">Y)B<5,`ZPDH`$``(/F_TG!Y@5,`>E)
MB?5),=5-,>5)`<U(B>E(P>D;3`GQ00'-3(GA2,'I`DG!Y!Y-B>Y,">%)B<1,
M`Z0DJ`$``(/A_TG!Y@5,`>))B<Q),?1),>Q)`=1,B>I(P>H;3`GR00'42(GJ
M2,'E'DC!Z@)-B>9(">I(B<5(`ZPDL`$``(/B_TG!Y@5(`>Y(B=5(,<U,,>U(
M`?5,B>9(P>X;3`GV`?5,B>Y)P>4>2,'N`DF)[DP)[DF)Q4P#K"2X`0``@^;_
M3`'I28GU23'533'E2<'F!4D!S4B)Z4C!Z1M,"?%!`<U,B>%)P>0>2,'I`DV)
M[DP)X4F)Q$P#I"3``0``@^'_2<'F!4P!XDF)S$DQ]$DQ[$D!U$R)ZDC!ZAM,
M"?)!`=1(B>I(P>4>2,'J`DV)YD@)ZDB)Q4@#K"3(`0``@^+_2<'F!4@![DB)
MU4@QS4PQ[4@!]4R)YDC![AM,"?8!]4R)[DC![@))P>4>28GN3`GN28G%3`.L
M)-`!``"#YO])P>8%3`'I28GU23'533'E20'-2(GI2,'I&TP)\4$!S4R)X4G!
MY!Y(P>D"38GN3`GA28G$3`.D)-@!``"#X?])P>8%3`'B28G,23'T23'L20'4
M3(GJ2,'J&TP)\D$!U$B)ZDC!Y1Y(P>H"38GF2`GJ2(G%2`.L).`!``"#XO](
M`>Y(B=5(,<U,,>U(`?5,B>9)P>8%2,'N&TP)]@'U3(GN2<'E'DC![@))B>Y,
M">Y)B<5,`ZPDZ`$``(/F_TG!Y@5,`>E)B?5),=5-,>5)`<U(B>E(P>D;3`GQ
M00'-3(GA2<'D'DC!Z0)-B>Y,">%)B<1,`Z0D\`$``(/A_TG!Y@5,`>))B<Q)
M,?1),>Q)`=1,B>I(P>H;3`GR00'42(GJ2,'E'DC!Z@)-B>9(">I(B<5(`ZPD
M^`$``(/B_TG!Y@5(`X0D``(``$@![DB)U4@QS4@!P4PQ[4@!]4R)YDC![AM,
M"?9$C30N3(GN2<'E'DC![@),B>5,">Y-B>5(P>T"@^;_2<'E'D4!\4B)\$P)
M[40!WD@QT$$!Z@':3#'@38GT2`'!3(GP2<'D!4C!Z!M,">`!R$$!P$R)!TR)
M3PA,B5<02(EW&$B)5R!(@<0(`@``6UU!7$%=05Y!7\-F#Q]$``!!5TF)]T%6
M055)B?U!5%532(/L"$B%_W1M3(LU$)<@`$V%]G1A#[8'/#UT=(3`='!)B?Q)
M@\0!00^V!"0\/70$A,!U[T4I[$F+'C'`2(7;=#=-8^1,B?5F#Q^$``````!,
MB>),B>Y(B=_H\N'__X7`=0="@#PC/70O2(/%"$B+70!(A=MUVC'`2(/$"%M=
M05Q!74%>05_#9@\?A```````13'DZZ(/'P!,*?5*C40C`4C!_0-!B2](@\0(
M6UU!7$%=05Y!7\-F+@\?A```````2(/L&#'`2(UT)`SH(/___TB#Q!C#9F8N
M#Q^$``````!32(G[2(/L$`\?A```````2(UT)`PQP$B)W^CQ_O__2(7`="Y(
M8T0D#$B+%1"6(`!(C03"2(M0"$B%TDB)$'302(/`"$B+4`A(A=)(B1!U\.N^
M2(/$$%O##Q^$``````!5,?]32(/L".BCY?__BSCHS./__TB)Q^A$XO__2(L`
M,?](BV@(Z(;E__^+..BOX___2(G'Z&?A__\Q_P^V&.AMY?__BSB#XW_HD^/_
M_TB)Q^C+X?__2(L`,?\/MT`@P>`'"=AFB44"Z$3E__^+..AMX___2(G'Z.7A
M__](BP`Q_TB+6`CH)^7__XLXZ%#C__\QTKY@74``2(G'Z#'C__\Q_TB)0RCH
M!N7__XLXZ"_C__](B<?HI^'__TB+`#'_2(M8".CIY/__BSCH$N/__TB)Q^BJ
MY/__2(L`,?](B4,PZ,SD__^+..CUXO__2(G'Z&WA__](BP`Q_TB+6`CHK^3_
M_XLXZ-CB__](B<?HL.3__S'22(,X`'0@,?_HD>3__XLXZ+KB__](B<?HDN3_
M_TB+`$B+D*@```!(B5,X,?_H;>3__XLXZ);B__](B<?H#N'__TB+`#'_2(M`
M"$C'0$``````Z$CD__^+..AQXO__2(G'Z.G@__](BP`Q_TB+0`A(QT`@````
M`.@CY/__BSCH3.+__TB)Q^C$X/__2(L`,?](BU@(Z`;D__^+..@OXO__2(G'
MZ/?@__](BP!(B4-(2(/$"%M=PV8/'X0``````$B)7"382(EL).!(B?M,B60D
MZ$R);"3P3(ET)/A(@>RX````2(7_=`6`/P!U,TB+G"20````2(NL))@```!,
MBZ0DH````$R+K"2H````3(NT)+````!(@<2X````PP\?`.B+W___2(7`2(G%
M=,`/'P!(B>_H:.+__TB%P$F)Q`^$I````$&`?"03+@^$L````$V-;"032(G?
MZ*/?__],B>])B<;HF-___T6-=`8"26/^Z&OA__]-B>E)B<1(B<=)B=BYA%M`
M`$C'PO____^^`0```#'`Z"?C__^_`0```$B)XDR)YNCWWO__@_C_3(GG=!"+
M1"08)0#P```]`$```'1OZ"K>__],B>?H`M[__TB)[^C*X?__2(7`28G$#X5B
M____9@\?1```2(GOZ`#@__](B=_H^-[__^GP_O__#Q\`08!\)!0`#X0D____
M08!\)!0N#X4X____08!\)!4`#X0,____Z2?___\/'X``````Z(O^___KCV8/
M'X0``````%4Q[5-(B?LQ_TB#[`CH3N+__XLXZ'?@__](B<?HK]W__TB)WDB)
MPK\!````Z*_A__^%P'0+2(/$"(GH6UW#9I`Q_^@9XO__BSCH0N#__TB)Q^AZ
MW?__BT`8)0#P```]`$```'0E,?_H].'__XLXZ!W@__](B<?H5=W__XM`&"4`
M\```/0"@``!UJTB)W[X"````,>WH]^#__X7`0`^4Q4B#Q`A;B>A=PP\?A```
M````05<QP$%6055!5%5(B?U32(GS2(/L*(`^/0^4P$@!PTB)W^CIW?__2(UT
M)!Q!B<5(B>\QP.AW^O__2(7`28G$#X0+`0``2(G'Z,/=__]$B>DQTD@YR`^#
MS0```$2+9"0<#[9%`#P]#X2D`0``A,`/A)P!``!(B>CK"P\?@`````"$TG0,
M2(/``0^V$(#Z/77P2(L-29$@`$$I[4&-?`4"3HTDX>A(W___2(7`28D$)`^$
M8P$``(M4)!Q(BP4@D2``2(L$T`^V50"$TH@0="F`^CUT)$B#Q0'K#`\?@```
M``"`^CUT$@^V50!(@\`!2(/%`832B!!UZ<8`/3'2#Q]```^V#!.(3!`!2(/"
M`83)=?`QP$B#Q"A;74%<05U!7D%?PP\?@``````/M@0308@$%$B#P@&$P'38
M#[8$$T&(!!1(@\(!A,!UX.O&9@\?1```3(L]B9`@`$4QY+X0````28,_`'0E
M3(GX#Q^$``````!(@\`(08/$`4B#.`!U\D&-="0"2&/V2,'F`XL]D)`@`(7_
M=#1,B?_HY-[__TB%P$F)QDB)!3>0(`!T;4ECS$G'1,X(`````$2)9"0<Z9_^
M__\/'X``````2(GWQP5+D"```0```.@6WO__2(7`28G&=#9)8\Q,B?Y(B<=(
MC13-`````$B)3"0(Z*/>__],B37<CR``2(M,)`CKHP\?1```2(GHZ7C^__^X
M_____^GP_O__9F9F9F8N#Q^$``````!(B5PDZ$R)9"3X2(G[2(EL)/!(@>PH
M$```28GTNO\/``!(B>:_BEM``&1(BP0E*````$B)A"0($```,<#HW]K__X7`
M#XY_````C5#_2&/J@#PL`'1K2&/H2(GJOB\```!(B>?HN-S__TB%P'1;,?_H
M#-___XLXZ#7=__](B>E(B>)(B=Y(B<?H1-[__TB+A"0($```9$@S!"4H````
M=4=(BYPD$!```$B+K"08$```3(ND)"`0``!(@<0H$```PY"%TG64#Q]``#'_
MZ+'>__^+..C:W/__3(GB2(G>2(G'Z'S;___KIN@5V___#Q]$``!(@^P(,?_H
MA=[__XLXZ*[<__^YF5M``+I@'D``OJ-;0`!(B<=(@\0(Z</<__\/'P!(@^P(
M,?_H5=[__XLXZ'[<__](B<?HMO___S'_Z#_>__^+..AHW/__0;A@74``13')
MNL!50`!,B<&^OUM``$B)QTB#Q`CIUMS__V8/'T0``%53,=M(@>PH(```9$B+
M!"4H````2(F$)!@@```QP.BMV?__0;F56T``08G`N=1;0``QP+H!$```O@$`
M``!(B>?HZ]W__X7`>$A(C;0D$!```+H`$```2(GGZ%+9__^%P(G%>"V-?0%(
M8__HX=O__TB%P$B)PW0:2&/M2(VT)!`0``!(B<=(B>KH4]O__\8$*P!(BY0D
M&"```&1(,Q0E*````$B)V'4*2('$*"```%M=P^C:V?__9BX/'X0``````.D[
M____9F8N#Q^$``````!!54F)]4%454B)_;_B6T``4TB!["@0``!D2(L$)2@`
M``!(B80D&!```#'`Z.#V__^^+P```$B)[TB)P^B@V?__2(7`=#=(B>Z_ZUM`
M`#'`Z#S[__](BY0D&!```&1(,Q0E*````$B)Z`^%6@$``$B!Q"@0``!;74%<
M05W#2(GOZ!S9__],B>^^^%M``$&)Q.CLV___28G%9@\?A```````387M=*!!
M@'T``+C@6T``3`]$Z$B%VW033(GN2(G?Z%W:__^%P`^$M0```$R)[^C-V/__
M2&/008!\%?\O=1E)C505_P\?1```Q@(`2(/J`8/H`8`Z+W3Q08U$!`$]_P\`
M``^//O___TB-?"000;GZ6T``38GHN1%=0`"Z`!```+X!````,<!(B2PDZ#'<
M__\Q_^@*W/__BSCH,]K__TB)Q^AKU___2(UT)!!(B<*_`0```.CIU___A<!U
M)3'_Z-[;__^+..@'VO__2(G'Z#_7__^+0!@E`/```#T`@```=!2^^%M``#'_
MZ/3:__])B<7I#/___TB-?"00O@$```#HS=K__X7`==E(C70D$+_K6T``Z-KY
M__](C7PD$.@`V?__2(G%Z8S^___H\]?__P\?``^V#TB)^(3)=!E(C5<!9I"`
M^2](#T3"2(/"`0^V2O^$R77M\\-F9BX/'X0``````$B%_U-(B?MT)X`_`'0B
MZ(W7__](C50#_T@YTW(,ZS^02(/J`4@YVG1_@#HO=/+K);\"````Z$;9__](
MA<!T!6;'`"X`6\-F+@\?A```````@#HO=`E(@^H!2#G3<O)(.=IT10\?1```
M2(/J`4@YTW,%@#HO=/)(*=HQP$B-2@)(@?D`$```=[Q(B=Y(@\(!N0`0``"_
M(--@`.A"V?__N"#38`!;PP\?`(`Z+W0+6[_Z6T``Z0C8__^_`@```.B^V/__
M2(G",<!(A=(/A'3___]FQP(N`$B)T%O#9@\?1```2(/L.+_\6T``9$B+!"4H
M````2(E$)"@QP$B+!2`5``!(B00D2(L%'14``$B)1"0(2(L%&14``$B)1"00
M2(L%%14``$B)1"08#[<%$14``&:)1"0@,<#H]?/__S'`OP5<0`#HZ?/__S'`
MOPU<0`#HW?/__S'`OQ9<0`#HT?/__S'`OQU<0`#HQ?/__S'`ORU<0`#HN?/_
M_S'`O^);0`#HK?/__S'`OSE<0`#HH?/__S'`OT-<0`#HE?/__S'`OTU<0`#H
MB?/__S'`O^M;0`#H??/__S'`OU=<0`#H<?/__S'`OV!<0`#H9?/__S'`OVM<
M0`#H.?/__TB%P'0/2(G&OT-<0``QP.BE]___,<"_?%Q``.@9\___2(7`=`](
MB<:_CEQ``#'`Z(7W__\QP+^97$``Z/GR__](A<!T/$B)QK_B6T``,<#H9??_
M_S'`OL5<0`"_'5Q``.A4]___2(M$)"AD2#,$)2@```!U6DB#Q#C##Q^`````
M`#'`OZE<0`#HK/+__TB%P'072(G&OSE<0``QP.@8]___Z[%F#Q]$``!(C70D
M$;^Z7$``N0H```#SIG682(UT)!N_.5Q``#'`Z.SV___KA>@5U?__#Q]$``!(
M@^P(BP6&B"``@_C_=`E(@\0(PP\?0``QP+\Y7$``Z#SR__](B<(QP$B%TG0/
M#[82A-)T"#'`@/HP#Y7`B05-B"``2(/$",,/'X0``````$B#[`CHQ]3__XG'
MZ&#4__](A<!T"TB+`$B#Q`C##Q\`,<#K]&9F9BX/'X0``````$%6055!5$F)
M_%53N]%<0`!(@^Q`2,=$)!#17$``2,=$)!C'7$``2(UL)!A(QT0D(-1<0`!(
MQT0D*,I<0`!(QT0D,,]<0`!(QT0D.&!=0`#K(0\?@`````!(B<?HD-?__TB%
MP'1+2(M=`$B#Q0B`.P!T,3'`2(G?Z&3Q__](A<!)B<9,B>9T!8`X`'7,2(G?
M,<#HRO7__TB+70!(@\4(@#L`=<](@\1`6UU!7$%=05[#3(GGZ+C3__],B?=)
MB<7HK=/__TF-?`4"Z(/5__]!N?A;0`!)B<5(B<=-B>"Y$5U``$C'PO____^^
M`0```#'`3(DT).@XU___3(GN2(G?,<#H6_7__^N/9@\?A```````05=!5D%5
M05154TB)^[_B6T``2('LB($``&1(BP0E*````$B)A"1X@0``,<!(QT0D<.U<
M0`!(QT0D>/5<0`!(QX0D@````.!;0`!(QX0DB````&!=0`!(QT0D0(Y<0`!(
MQT0D2(=<0`!(QT0D4/I<0`!(QT0D6/!<0`!(QT0D8`)=0`!(QT0D:&!=0`!(
MQX0DD````.%<0`!(QX0DF`````9=0`!(QX0DH````&!=0`#H&_#__TB%P'0)
M@#@`#X7]`@``,<#H]OW__TB%P$F)Q@^$$@,``$$/MBY`A.UT+>@,UO__3(GR
M9@\?A```````2(L(2`^^[?8$:0AU`\8"7TB#P@$/MBI`A.UUY$&\`0```+^.
M7$``ZQP/'X``````26/$08/$`4B+?,1`@#\`#X0K`@``,<#HE.___TB%P$B)
MQ73<2(G'Z%3S__^%P'302(GOZ"C3__](A<!)B<5TP$R)[^CXT?__3(GW2(G%
MZ.W1__]$C:0%!`0``$UCY$R)Y^BZT___3(GG2(G%Z*_3__]!N?I;0`!-B>BY
M#UU``$C'PO____](B<=)B<2^`0```#'`3(ET)`A(QP0D&%U``.A;U?__ONT!
M``!,B>?HKM#__S'`O\I<0`#H\N[__TB%P`^$60(``$B)Q^B1TO__2(L[2(G&
MZ,;W__](A<!)B<4/A#H"``!,B>_H4M'__X/X`WXU2&/0OQU=0`"Y!0```$F-
M=!7\\Z9U'X/X!`^$[@8``(/H!$B808!\!?\O#X3=!@``#Q]$```QP.@A_/__
MA<!U%3'V3(GOZ(/3__^%P$&)Q@^%Z`$``+[%7$``OSE<0``QP.C7\O__Z$+0
M__]!N?I;0`")!"1-B>"Y.UU``$C'PO____^^`0```$B)[S'`2,=$)`A@74``
M,=OH<-3__^M,9@\?1```Z(//__^#.!%U3NCYS___@\,!B00D0;GZ6T``38G@
MN4E=0`!(Q\+_____O@$```!(B>\QP$C'1"008%U``(E<)`CH(M3__[[M`0``
M2(GOZ'7/__^#^/]TJ$R)Y^@8S___O^);0`!(B>XQP.@I\O__2(GOZ,'[__](
MBY0D>($``&1(,Q0E*````$B)Z`^%UP8``$B!Q(B!``!;74%<05U!7D%?PP\?
M1```2(ML)'!!O`$```"`?0``=1GK/0\?1```26/$08/$`4B+;,1P@'T``'0F
M2(GOZ`[Q__^%P'3B2(GOZ.+0__](A<!)B<5TTNFU_?__#Q]$``!%,>WIJ/W_
M_P\?A```````2(G'2(E$)"#H(_O__TB+1"0@2(G'Z*;0__](B<7I3?___V8/
M'T0``+T!````O^%<0`!F#Q]$```QP.C1[/__2(7`=!1(B<?H=-#__TB%P$F)
MQ@^%OOS__TACQ8/%`4B+O,20````@#\`=<U!ON9<0`#IUOS__V8N#Q^$````
M``!,BROIOOW__P\?A```````N@(```!(Q\;N____B<?H/=+__TB-M"2P````
MN@8```!$B??H.-#__X"\)+``````=0Z`O"2Q````0P^$#`4``#'2,?9$B??H
M!-+__TB-G"3H@```0;B)J\WO0;G^W+J80;KPX=+#2,>$)+"````!(T5G3(F$
M)+B```!,B8PDP(```$C'A"3(@```=E0R$$R)E"30@```2,>$)-B`````````
M2,>$)."`````````QX0D*($````````/'X``````2(VT)+````"Z`(```$2)
M]^B+S___A<!!B<4/CH`!``!(BXPDV(```$ECQ8N\)"B!``!,C;PDL````(T4
MP4@YRDB)E"38@```#Y+!2,'H'0^VR4@!C"3@@```2`&$)."```"%_W1J0;]`
M````2(VT)+````!!*?](8_]%.?U%#T[]2`'?26/'2(G"2(E$)"CH+,___XN$
M)"B!``!$`?B#^$")A"0H@0``#X52____2(V\)+"```!%*?U,C;PDL````$P#
M?"0HZ&74__\/'T0``$&#_3\/CJ0```!!C57`P>H&B=")5"0T2(E$)#A(P>`&
M28U$!T!(B40D*$R)^`\?`$B+$$B-O"2P@```2(D32(M0"$B)4PA(BU`02(E3
M$$B+4!A(B5,82(M0($B)4R!(BU`H2(E3*$B+4#!(B5,P2(M0.$B#P$!(B5,X
M2(E$)"#HW-/__TB+1"0@2#M$)"AUH$B+1"0X2(/``4C!X`9)`<>+1"0T]]C!
MX`9%C6P%P$ECU;E(````3(G^2(G?Z%_.__]$B:PD*($``.EB_O__9I!$B??H
M>,W__TB+G"38@```3(NL)."```!(B=A(P>@#@^`_C4@!2&/0QH04Z(```("#
M^3@/CW`"``"Z-P```$ACR3'V*<)(C;P,Z(```$ACTNCKS/__3(GH2(V\)+"`
M``!$B*PD(X$``$C!Z!B(G"0G@0``B(0D(($``$R)Z$C!Z!"(A"0A@0``3(GH
M3(VL)#"!``!(P>@(B(0D(H$``$B)V$C!Z!B(A"0D@0``2(G82,'H$(B$)"6!
M``!(B=@QVTC!Z`B(A"0F@0``Z,'2__](BX0DL(```$B)PHB$)&.!``!(P>H8
M08G0B)0D8($``$B)PDC!ZA"(E"1A@0``2(G"2(N$)+B```!(P>H(B)0D8H$`
M`$B)PHB$)&>!``!(P>H8B)0D9($``$B)PDC!ZA"(E"1E@0``2(G"2(N$),"`
M``!(P>H(B)0D9H$``$B)PHB$)&N!``!(P>H8B)0D:($``$B)PDC!ZA"(E"1I
M@0``2(G"2(N$),B```!(P>H(B)0D:H$``$B)PHB$)&^!``!(P>H8B)0D;($`
M`$B)PDC!ZA"(E"1M@0``2(G"2(N$)-"```!(P>H(B)0D;H$``$B)PHB$)'.!
M``!(P>H8B)0D<($``$B)PDC!ZA"(E"1Q@0``2(G"2,'J"(B4)'*!``#I#0``
M``\?0`!$#[:$'&"!``!)C7Q=`#'`10^VP+DV74``2,?"_____[X!````2(/#
M`>A*SO__2(/[%'7,QH0D6($```!(QT0D"&!=0`!,B2PD0;GZ6T``38G@N2==
M0`!(Q\+_____O@$```!(B>\QP.@+SO__Z?;Y__]F#Q]$``!(BUL(2(7;#X0;
M^?__2(G?Z"O*__](@_@##X8)^?__2(UT`_R_(EU``+D%````\Z9,#T3KZ>_X
M__](8\FZ/P```#'V2(V\#.B````IPDACTNA[RO__2(V\)+"```#HOM#__TB-
ME"3H@```N0<````QP$B)U_-(J^EI_?__@+PDL@```$$/A>;Z__^`O"2S````
M0P^%V/K__X"\)+0```!(#X7*^O__@+PDM0```$4/A;SZ__^Z`@```$C'QL;_
M__]$B??HN,S__TB-M"2P````NBD```!$B??HL\K__TB-E"2P````2,=$)`A@
M74``2(D4).G:_O__9@\?A```````Z%O)__]F9BX/'X0``````$%5,?]!5%53
M2(/L".B_S/__BSCHZ,K__TB)Q^CPR?__OQU<0`#&``$QP.AQYO__2(7`=`F`
M.#$/A*,"```QP.@L\O__,?_HA<S__XLXZ*[*__^Y"P```+H!````OEI=0`!(
MB<?H5\K__TB%P`^$MP```$B+0!`QVTR+8"B+!>:,(`"#^`$/CI,```"]"```
M`.LR9@\?1```28MU$$B+!;V,(`!(BSPHZ`3*__^%P'5H@\,!BP6OC"``2(/%
M"(U3`3G0?EHQ_^@%S/__BSCH+LK__S')B=I,B>9(B<?H_\K__TB%P'0R3(LH
M0?9%#01UJ#'_Z-G+__^+..@"RO__3(GNN0(````QTDB)Q^C0R/__2(G&ZX</
M'P"+!4J,(`"-4/\YV@^$3P$``#'_Z*#+__^+..C)R?__N00```"Z`0```+Y?
M74``2(G'Z'+)__](A<!(B<-T-DB+0!`Q_TB+*.ALR___BSCHE<G__[IA74``
M2(G'2(GNZ#7(__](BT,02(L8]D,.0`^%-`$``#'_Z#W+__^+..AFR?__N00`
M``"Z`0```+YI7$``2(G'Z`_)__](A<!(B<-T.S'`O^M;0`#HV^3__TB%P$F)
MQ`^$)P$``$B+0Q`Q_TB+*.CQRO__BSCH&LG__TR)XDB)[DB)Q^B\Q___,?_H
MU<K__XLXZ/[(__](B<?H!LC__S'_Q@``Z+S*__^+..CER/__2(G'Z#W&__^_
MXEM``$C'```````QP.AJY/__2(7`2(D%,(L@``^$X0```+[M`0``2(G'Z/W%
M__^#^!%T#H7`=`J#^/^0#X4H`0``2(/$"%M=05Q!7<,/'X``````@_@!#XZH
M_O__NP$```!F+@\?A```````,?^#PP'H-LK__XLXZ%_(__],B>9(B<?HU,7_
M_SD=MHH@`'_<Z7#^__\/'X``````,?_H"<K__XLXZ#+(__](B=Y(B<?HA\C_
M_^FN_O__9I"`>`$`#X1:_?__9@\?1```Z4C]__\/'P!(BP5ABB``,?],BR!(
MBT,02(LHZ,#)__^+..CIQ___3(GF2(GOZ"[J___IS?[__TB+/3**(`#HG?+_
M_TB)!3:*(`!(BT,02(LM&XH@`$R+($'V1"0-!'1_28M$)!!(B>Y(B<?HT,C_
M_XG%2(M#$$B+&/9##01T/DB+0Q!(B<)(BP7CB2``B>F_F%U``$B+,#'`Z)+'
M__^)P4B+!<F)(`!(BQ72B2``O\A=0`!(BS`QP.ASQ___,?_H',G__XLXZ$7'
M__^Y`@```#'22(G>2(G'Z!/&___KI#'_Z/K(__^+..@CQ___N0(````QTDR)
MYDB)Q^CQQ?__Z6'___]F9F8N#Q^$``````!52(G]4TB#[`CH@NW__P^V$$B)
MPX32=!M(C4`!#Q]``(#Z+T@/1-A(@\`!#[90_X32=>TQP.@&\/__A<!T'4B%
M[708@'T``'02OAA=0`!(B=_H6LC__T@YV'0'2(/$"%M=PTB#Q`A(B>];7>F`
MY/__2(/L"#'_Z%7(__^+..A^QO__OO____](B<?HH<7__S'_Z#K(__^+..AC
MQO__,=*^X#Q``$B)QTB#Q`CIT,?__TB-!1%X(`!(A<!T#$B+#05X(`#I>,7_
M_S')Z_>0D)"02(EL)-A,B60DX$B-+6-S(`!,C25<<R``3(EL).A,B70D\$R)
M?"3X2(E<)-!(@^PX3"GE08G]28GV2,']`TF)U^C#PO__2(7M=!PQVP\?0`!,
MB?I,B?9$B>]!_Q3<2(/#`4@YZW+J2(M<)`A(BVPD$$R+9"083(ML)"!,BW0D
M*$R+?"0P2(/$.,,/'X``````\\.0D)"0D)"0D)"0D)"0D%5(B>532(/L"$B+
M!<AR(`!(@_C_=!F[",Y@``\?1```2(/K"/_02(L#2(/X_W7Q2(/$"%M=PY"0
M2(/L".B_R?__2(/$",,``````````````0`"`"5S+R5S`"]P<F]C+W-E;&8O
M97AE`'!E<FQX<VDN8P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT
M97)N86QS.CI005(Z.D)/3U0`+W!R;V,O)6DO)7,`+@!005)?5$5-4`!005)?
M4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/
M`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%
M0E5'`%!!4E]#04-(10!005)?05)'0P!005)?05)'5E\P`%!!4E]'3$]"04Q?
M1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,
M7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$E"4$%42`!$
M64Q$7TQ)0E)!4EE?4$%42`!54T52`%-94U1%30!#.EQ414U0`"]T;7``5$5-
M4$1)4@!435``55-%4DY!344`)7,E<R5S)7,`<&%R+0!P87)L`"YP87(`)7,E
M<V-A8VAE+25S)7,`)3`R>``E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U
M)7,`05)'5@`8`'!E<FP`+64`+2T``````%]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@```````````E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE
M9"`M(&%B;W)T:6YG('=I=&@@)6DN"@`E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!T96UP;W)A<GD@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`M(&%B;W)T:6YG
M('=I=&@@)6DN"@``````````````````````P$,`````````````````````
M```````````C(2]U<W(O8FEN+W!E<FP*979A;"`G97AE8R`O=7-R+V)I;B]P
M97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P.R`C(&YO="!R=6YN:6YG
M('5N9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P87)?<&P["@HC("TM+2!4
M:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@870@8V]M<&EL
M92!T:6UE("TM+0HC('5S92!S=')I8W0["@HC;&EN92`Q-3@*"FUY("@D<&%R
M7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@
M("`@;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?
M=&5M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E
M;7`B?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I
M(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*("`@(')M9&ER("1P
M87)?=&5M<#L*("`@(",@1&]N)W0@<F5M;W9E('1O<&1I<B!B96-A=7-E('1H
M:7,@8V%U<V5S(&$@<F%C92!W:71H(&]T:&5R(&%P<',*("`@(",@=&AA="!A
M<F4@=')Y:6YG('1O('-T87)T+@H*("`@(&EF("@M9"`D<&%R7W1E;7`@)B8@
M)%Y/(&YE("=-4U=I;C,R)RD@>PH@("`@("`@(",@4V]M971H:6YG('=E;G0@
M=W)O;F<@=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T;W)Y+B`@5&AI
M<PH@("`@("`@(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA=&9O<FUS('1H
M870@9&ES86QL;W<@=6YL:6YK:6YG('-H87)E9`H@("`@("`@(",@;&EB<F%R
M:65S(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N(%5N;&EN:R!W
M:71H(&$@8F%C:V=R;W5N9`H@("`@("`@(",@<VAE;&P@8V]M;6%N9"!S;R!T
M:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI<R!P<F]C97-S
M+@H@("`@("`@(",@1&]N)W0@9&\@86YY=&AI;F<@;VX@5VEN9&]W<R!B96-A
M=7-E(&]U<B!P87)E;G0@<')O8V5S<R!W:6QL"B`@("`@("`@(R!T86ME(&-A
M<F4@;V8@8VQE86YI;F<@=&AI;F=S('5P+@H*("`@("`@("!M>2`D=&UP(#T@
M;F5W($9I;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%35!,051%(#T^("=T;7!8
M6%A86"<L"B`@("`@("`@("`@($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER
M;F%M92@D=&]P9&ER*2P*("`@("`@("`@("`@4U5&1DE8(#T^("<N8VUD)RP*
M("`@("`@("`@("`@54Y,24Y+(#T^(#`L"B`@("`@("`@*3L*"B`@("`@("`@
M<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P
M(%T[(&1O"B`@(')M("UR9B`G)'!A<E]T96UP)PH@("!I9B!;(%PA("UD("<D
M<&%R7W1E;7`G(%T[('1H96X*("`@("`@(&)R96%K"B`@(&9I"B`@('-L965P
M(#$*("`@>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL
M96YA;64@+B`B)PHB.PH@("`@("`@("`@("!C:&UO9"`P-S`P+"1T;7`M/F9I
M;&5N86UE.PH@("`@("`@(&UY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@
M/B]D978O;G5L;"`R/B8Q("8G.PH@("`@("`@(&-L;W-E("1T;7`["B`@("`@
M("`@<WES=&5M*"1C;60I.PH@("`@("`@(&]U=',H<7$H4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"B`@("`@("`@
M("`@("`N("1T;7`M/F9I;&5N86UE*3L*("`@('T*?2!]"@I"14=)3B!["B`@
M("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*
M:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=6
M7S!]("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@
M*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM005)?
M05)'5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@
M("`@9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*("`@('T*?0H*
M;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M
M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T
M:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@
M("!?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I
M;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S971?<')O9VYA
M;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI
M;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T
M87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?
M7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R
M="!O9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D<')O
M9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F
M.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#@[
M"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S
M965K(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!S
M965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#(["B`@("!R96%D
M(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L*("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O
M(&UE;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@("!W:&EL92`H
M)&)U9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*
M("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@
M("`@("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@("`@;W5T<RAQ<2A5
M;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@("`@(&UY("1C
M<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q
M(#H@=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@("!R96%D(%]&
M2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I(&%N9"`D97AT
M("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@("`@("!M>2`H
M)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*("`@
M("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H
M)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@
M("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@("`@8VAM;V0@
M,#<U-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*
M("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65]
M(#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H("1F=6QL
M;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-
M4'T@*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP
M9FEL92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D14Y6>U!!4E]4
M14U0?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@("`@;W5T<R@B4TA,24(Z
M("1F:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG
M+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1O
M=70I.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@
M(&-L;W-E("1O=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@
M("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@("`@("`@("`D
M4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*("`@("`@
M("`@("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@("`@8W)C(#T^
M("1C<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^("1F=6QL;F%M92P*("`@
M("`@("`@("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?1D@L("1B=68L
M(#0["B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B('L*
M("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@("`@("`@(')E
M='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@("`@("`@;7D@
M)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@
M9&\@>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E86-H
M("AK97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@("`@(&YE>'0@
M=6YL97-S("]<421M;V1U;&5<120O.PH@("`@("`@("`@("`@("`@)&ME>2`]
M("1?.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["B`@("`@("`@
M?2!O<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@/2`B+VQO861E
M<B\D9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D14Y6>U!!4E]#
M3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["B`@("`@("`@
M("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$[
M"B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<')I;G0@
M)&9H("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E96LH)&9H+"`P
M+"`P*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"B`@("`@
M("`@96QS92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M
M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@("`@("`@("!I
M9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@
M("`@("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@
M("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PH@("`@
M("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E='5R;B`D9F@[
M"B`@("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D
M.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)3D,I.PH*("`@
M(",@3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@>WM["@H@("`@(R!I;FET
M:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER92!8
M4TQO861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@
M0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@
M(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L
M970G<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@
M("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S="!O9B!T:&4@
M9W)O=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES
M("5R97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W
M9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@
M("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)3
M1%!!3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T
M:&5R(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@*"1F:6QE;F%M
M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R97%U:7)E("1F
M:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I=&5C=7-T;VUI
M>F4N<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@
M("`@("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1F:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L87-T('5N;&5S
M<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L
M;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C97-S:6YG('M[
M>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C
M86-H95]N86UE*3L*"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A
M;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0H*)'%U
M:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PHC($1O;B=T('-W86QL
M;W<@87)G=6UE;G1S(&9O<B!C;VUP:6QE9"!E>&5C=71A8FQE<R!W:71H;W5T
M("TM<&%R+6]P=&EO;G,*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E
M<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["B`@("!M>2`E9&ES=%]C
M;60@/2!Q=R@*("`@("`@("!P("`@8FQI8E]T;U]P87(*("`@("`@("!I("`@
M:6YS=&%L;%]P87(*("`@("`@("!U("`@=6YI;G-T86QL7W!A<@H@("`@("`@
M(',@("!S:6=N7W!A<@H@("`@("`@('8@("!V97)I9GE?<&%R"B`@("`I.PH*
M("`@(",@:68@=&AE(&%P<"!I<R!I;G9O:V5D(&%S(")A<'!N86UE("TM<&%R
M+6]P=&EO;G,@+2UR975S92!04D]'4D%-($!04D]'7T%21U8B+`H@("`@(R!U
M<V4@=&AE(&%P<"!T;R!R=6X@=&AE(&=I=F5N('!E<FP@8V]D92!I;G-T96%D
M(&]F(&%N>71H:6YG(&9R;VT@=&AE"B`@("`C(&%P<"!I='-E;&8@*&)U="!S
M=&EL;"!S970@=7`@=&AE(&YO<FUA;"!A<'`@96YV:7)O;FUE;G0@86YD($!)
M3D,I"B`@("!I9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@
M>PH@("`@("`@('-H:69T($!!4D=6.PH@("`@("`@("1%3E9[4$%27T%04%]2
M155317T@/2!S:&EF="!`05)'5CL*("`@('T*("`@(&5L<V4@>R`C(&YO<FUA
M;"!P87)L(&)E:&%V:6]U<@H*("`@("`@("!M>2!`861D7W1O7VEN8SL*("`@
M("`@("!W:&EL92`H0$%21U8I('L*("`@("`@("`@("`@)$%21U9;,%T@/7X@
M+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*"B`@("`@("`@
M("`@(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@("`@("`@('!U<V@@0&%D
M9%]T;U]I;F,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF
M("@D,2!E<2`G32<I('L*("`@("`@("`@("`@("`@(&5V86P@(G5S92`D,B([
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@
M>PH@("`@("`@("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L("0R.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G3R<I('L*("`@
M("`@("`@("`@("`@("1O=70@/2`D,CL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@("`@("`D8G5N
M9&QE(#T@)W-I=&4G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF
M("@D,2!E<2`G0B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@/2`G86QL
M)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)W$G
M*2!["B`@("`@("`@("`@("`@("`D<75I970@/2`Q.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*("`@("`@("`@("`@
M("`@(&]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T
M(&]P96X@;&]G.B`D(2(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS
M:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`@("`@)&-A8VAE7VYA;64@
M/2`D,CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<VAI9G0H0$%21U8I
M.PH*("`@("`@("`@("`@:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2![
M"B`@("`@("`@("`@("`@("!D96QE=&4@)$5.5GLG4$%27U1%35`G?3L*("`@
M("`@("`@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@("`@("`@("!R97%U
M:7)E(%!!4CHZ1&ES=#L*("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"D@=6YL97-S($!!4D=6.PH@("`@("`@("`@("`@("`@)GLB4$%2
M.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@("`@("`@("`@
M(&5X:70["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@('5N<VAI
M9G0@0$E.0RP@0&%D9%]T;U]I;F,["B`@("!]"GT*"B,@6%A8("TM(&%D9"`M
M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/
M*2!H86YD;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*("`@("`@("`C;&]C
M86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN
M,S(G.PH@("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER
M92!!<F-H:79E.CI::7`["B`@("!]"@H@("`@;7D@)'!A<B`]('-H:69T*$!!
M4D=6*3L*("`@(&UY("1Z:7`["@H*("`@(&EF("AD969I;F5D("1P87(I('L*
M("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T
M(&9I;F0@)R1P87(G.B`D(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@
M("`@(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!
M<F-H:79E.CI::7`M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I
M"B`@("`@("`@("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*
M("`@('T*"@H@("`@;7D@)65N=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A
M;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@
M("`@("`@("`@("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@
M("`@)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@("`@("`@("1M971A(#U^
M("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@
M(",@3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@
M)"\@/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E
M;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B
M:6YM;V1E*%!!4BD["B`@("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F
M:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@
M($-R96%T95!A=&@H)&]U="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W*`H@("`@("`@("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%
M050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)5
M3D,H*2P*("`@("`@("`P-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM
M;V1E*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D
M871A7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D
M;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"
M051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@
M("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*
M("`@('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*
M("`@("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@
M("1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@
M(&UY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*
M("`@("`@("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB
M.PH@("`@("`@("1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@
M("`@)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T
M:"@D<V5T*2DI"B`@("`@("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D
M;&]A9&5R*3L*("`@("0O(#T@=6YD968["B`@("`C('U]?0H*("`@(",@5W)I
M=&4@8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@
M("`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PH@("`@("`@(&EN:71?:6YC*"D["@H@("`@
M("`@(')E<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`:6YC(#T@<V]R
M="!["B`@("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@
M("`@("!](&=R97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*("`@("`@("!]
M(&=R97`@>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G<VET92<I(&]R"B`@
M("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B`@("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI
M8F5X<'TI.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@(R!&:6QE(&5X:7-T
M<R!T97-T(&%D9&5D('1O(&9I>"!25"`C-#$W.3`Z"B`@("`@("`@(R!&=6YN
M>2P@;F]N+65X:7-T:6YG(&5N=')Y(&EN(%\\+BXN+F%U=&\O0V]M<')E<W,O
M4F%W+UIL:6(O875T;W-P;&ET+FEX+@H@("`@("`@(",@5&AI<R!I<R!A(&)A
M;F0M86ED(&9I>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O9B!T:&4@:7-S=64N
M"B`@("`@("`@(R!3;VUE8F]D>2!P;&5A<V4@9V\@=&AR;W5G:"!T:&4@<&%I
M;B!O9B!U;F1E<G-T86YD:6YG('=H870G<R!H87!P96YI;F<L"B`@("`@("`@
M(R!)(&9A:6QE9"X@+2T@4W1E9F9E;@H@("`@("`@(&UY("5F:6QE<SL*("`@
M("`@("`O7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S>R0Q?2LK(&9O
M<B!K97ES("4Z.CL*("`@("`@("`D9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E
M24Y#.PH*("`@("`@("!M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML
M:6)?97AT?3L*("`@("`@("!M>2`E=W)I='1E;CL*"B`@("`@("`@9F]R96%C
M:"`H<V]R="!K97ES("5F:6QE<RD@>PH@("`@("`@("`@("!M>2`H)&YA;64L
M("1F:6QE*3L*"B`@("`@("`@("`@(&9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@
M>PH@("`@("`@("`@("`@("`@:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD7WTI('L*("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1?
M.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=
M*2E<6B]I*2!["B`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@
M/2`H)#$L("0R*3L*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*&TA7B]L;V%D97(O
M6UXO72LO*"XJ6UY#8UTI7%HA*2!["B`@("`@("`@("`@("`@("`@("`@:68@
M*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B`@
M("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"1R968L
M("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@96QS:68@*"UF("(D
M9&ER+R0Q(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N
M86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&YE>'0@=6YL97-S(&1E
M9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*("`@("`@
M("`@("`@;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D
M;&EB7V5X=%Q%)"\["B`@("`@("`@("`@(&]U=',H(&IO:6X@(B(L"B`@("`@
M("`@("`@("`@("!Q<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^
M>VYA;65](#H@)&9I;&4L"B`@("`@("`@("`@("`@("!Q<2@B+BXN*0H@("`@
M("`@("`@("`I.PH*("`@("`@("`@("`@;7D@)&-O;G1E;G0["B`@("`@("`@
M("`@(&EF("AR968H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N
M="`]("1F:6QE+3Y[8G5F?3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@("`@(&]P96X@1DE,12P@)SPG+"`D9FEL92!O
M<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@("`@("`@("`@("`@
M(&)I;FUO9&4H1DE,12D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`](#Q&
M24Q%/CL*("`@("`@("`@("`@("`@(&-L;W-E($9)3$4["@H@("`@("`@("`@
M("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N
M=&5N="P@)&9I;&4I"B`@("`@("`@("`@("`@("`@("`@:68@(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PH*
M("`@("`@("`@("`@("`@(",@1&\@;F]T(&QE="!84TQO861E<B!P:6-K('5P
M(&%U=&\O*B!F<F]M(&5N=FER;VYM96YT"B`@("`@("`@("`@("`@("`D8V]N
M=&5N="`]?B!S+V=O=&\@*W)E=')Y("MU;FQE<W,@*RXJ+V=O=&\@<F5T<GD[
M+PH@("`@("`@("`@("`@("`@("`@(&EF(&QC*"1N86UE*2!E<2!L8R@B6%-,
M;V%D97(N<&TB*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;W5T<RAQ
M<2A7<FET=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@("`@)&9H+3YP<FEN
M="@B1DE,12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L
M96YG=&@H)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'-P
M<FEN=&8H"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII
M<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*("`@("`@("`@("`@
M*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M8V]N=&5N="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D[
M"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C($YO=R!W<FET92!O
M=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R
M:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@("`D8V%C:&5?;F%M
M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@("!I9B`H(21C86-H
M95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*("`@
M("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I
M9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@
M("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ
M340U+3YN97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@
M1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@(&UY("1S:&%?=F5R
M<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@
M("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R
M<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T>"T^861D9FEL92@D
M;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@("`@("`@96QS92![
M"B`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T
M(BDI('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@
M("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@(&-L
M;W-E*"1F:"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C
M86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*
M("`@('T*("`@("1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@
M)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@
M("1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H+3YP<FEN="AP86-K
M*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B`@("`D9F@M
M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L;W-E.PH@("`@8VAM
M;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI=#L*?0HC('U]?0H*
M(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI[
M"B`@("!L87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["@H@("`@7V9I
M>%]P<F]G;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N
M9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER92!0
M05(["B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@
M('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I
M9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@1FEL93HZ1FEN
M9#L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*("`@(&UY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&
M:6QE+3YN97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O
M<B!D:64@(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D
M:64@(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M("`@("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S*'%Q*%PD14Y6>U!!
M4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@("!I9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P
M;VEN="$*("`@("`@("!F;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PH@("`@("`@("`@("!N97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PH@("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF
M:6QE3F%M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE
M(#U^(&U["B`@("`@("`@("`@("`@("!>"B`@("`@("`@("`@("`@("`O/W-H
M;&EB+PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I
M;VY]+RD_"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C
M:&YA;65]+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI"B`@("`@("`@("`@
M("`@("`D"B`@("`@("`@("`@('UX.PH@("`@("`@("`@("!M>2`D97AT<F%C
M=%]N86UE(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T7VYA;64@/2!&:6QE
M.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE
M*3L*("`@("`@("`@("`@:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D
M;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@("`@("`@("`@("`@
M(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR
M96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@('T@
M96QS92!["B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M
M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@("`@
M("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["B`@
M("`@("`@("`@("`@("!C:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@
M97$@(FAP=7@B.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@
M(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N
M+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/
M;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R
M96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L
M("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<
M+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@
M($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@
M(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L
M97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@
M)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I
M<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I
M<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@
M=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A
M=GD["B`@("!R97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT
M;#L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ
M4W!E8SL*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I
M9SL*("`@(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I
M;&4["B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!
M<F-H:79E.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2
M.CI(96%V>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!R97%U:7)E(&%T=')I8G5T97,[
M"B`@("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E
M(%=I;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M("`@(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@
M("`@979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*
M("`@(&5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C
M86QA<B!].PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A
M<G,@:6X@;7EL9'(O;6MT;7!D:7(N8PHC(%1H:7,@8V]D92!A;'-O(&QI=F5S
M(&EN(%!!4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M<%]E;G8A"G-U8B!?
M<V5T7W!A<E]T96UP('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@("`@("`D<&%R
M7W1E;7`@/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@9F]R96%C
M:"!M>2`D<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]4
M35!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@("`@("`@<7<H
M($,Z7%Q414U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@
M("`@("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@
M("`C(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L('LH
M)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@
M("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@
M("`@("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@
M('T*("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@
M("`@)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@
M)$5.5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S
M97)N86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D
M<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@("`@(&UK
M9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%
M04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@
M("`@("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@
M("`@("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A
M9"`D9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*
M("`@("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@
M("`@("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@
M(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@
M("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-
M1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O
M<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y
M"B`@("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I
M9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF
M("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G
M-2XS.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P
M<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@
M("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M8VQO<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@
M("`@("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@
M("`@("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@
M)'-T;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R
M7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT
M+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D
M9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.
M5GM005)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M
M92`D9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE
M.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I
M;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F
M:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I
M.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*(R!S86UE(&-O9&4@
M;&EV97,@:6X@4$%2.CI3971U<%!R;V=N86UE.CIS971?<')O9VYA;64*<W5B
M(%]S971?<')O9VYA;64@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?4%)/
M1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@
M("`@("`@)'!R;V=N86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\
M/2`D,#L*"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G
M;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA
M;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]0
M4D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI
M(#X](#`I('L*("`@("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N
M86UE*2!["B`@("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@
M?0H@("`@("`@(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*
M("`@("`@("`@("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@
M("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PH@("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!]
M(&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@
M<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE
M(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA
M;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@
M("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["B`@("!]"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R
M;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P
M<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*
M"B`@("`C(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W
M9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@
M("`@("`@("`@("`@("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7
M:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*("`@
M("1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I
M+R1P=V0D0V]N9FEG>U]D96QI;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@
M*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E
M='5R;CL*("`@('T@96QS92!["B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:
M141](#T@,CL*("`@('T*"B`@("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%
M04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@
M("`@("!D96QE=&4@)$5.5GLG4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ
M=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[
M)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C
M;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@
M("`@:68@*"1%3E9[4$%27U1%35!]*2!["B`@("`@("`@9&5L971E("1%3E9[
M4$%27T-,14%.?3L*("`@('T*("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%2
M7T=,3T)!3%]#3$5!3GTI('L*("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H
M)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%
M3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH
M7%,K*2\["B`@("!]"GT*"G-U8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I
M970["B`@("!I9B`H)&QO9V9H*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`
M7UQN(CL*("`@('T*("`@(&5L<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*
M("`@('T*?0H*<W5B(&EN:71?:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@
M("`@<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*("`@("`@("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET
M96%R8VAE>'`@<VET96QI8F5X<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N
M9&]R;&EB97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,*(R!4:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP
M86-K86=E(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R
M;V=N86UE.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*
M)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H
M)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?
M7T524D]2(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@,3`Q,@H*7U]%3D1?
M7PH`<&%R+G!L``````$;`SOP````'0```'QC__\,`0``C&C__ZP%``"<:___
M-`$``%R!__^$`0``+(+__^0!``!,@O___`$``*R"__\<`@``?(3__TP"``#\
MA?__=`(``*R&__^L`@``W(C___P"``#,B?__)`,``/R)__\\`P``3(K__U0#
M```,B___A`,``!R+__^<`P``[(S__]P#```<C?__]`,``/R-__\D!```S(__
M_T0$```<D/__9`0``$R0__^$!```7)'__\P$``",F___'`4``(R?__]<!0``
M_)___Y0%```\H/__U`4``%R@___L!0``[*#__Q0&```4``````````%Z4@`!
M>!`!&PP'")`!```D````'````&AB__\0!0````X01@X82@\+=PB``#\:.RHS
M)"(`````3````$0```!@:O__NA4```!"#A"/`D@.&(X#0@X@C01"#BB,!4$.
M,(8&00XX@P='#L`$`Y@5#CA!#C!!#BA"#B!"#AA"#A!"#@@```````!<````
ME````-!____&`````$(.$(\"10X8C@-"#B"-!$4.*(P%00XPA@9!#CB#!T0.
M0`)X"@XX00XP00XH0@X@0@X80@X00@X(2@M;#CA!#C!!#BA"#B!"#AA"#A!"
M#@@4````]````$"`__\5`````$0.(%`."``<````#`$``$B`__]8`````$$.
M$(,"1PX@`DX.$$$.""P````L`0``B(#__\<!````00X0A@)##AB#`T0.(`.\
M`0X800X000X(`````````"0```!<`0``*(+__W<!````388%@P96#L`!C@*-
M`XP$>0H."$0+```T````A`$``("#__^H`````$$.$(8"0PX8@P-)#B!L"@X8
M0PX000X(0PL"8PX800X00PX(`````$P```"\`0``^(/__R("````0@X0CP)$
M#AB.`T(.((T$0@XHC`5!#C"&!D0..(,'1PY@`P`!"@XX00XP00XH0@X@0@X8
M0@X00@X(2`L`````)`````P"``#8A?__ZP````!-C`*#!$P.L""&`P*E"@X(
M0@L``````!0````T`@``H(;__RT`````1`X09`X(`!0```!,`@``N(;__TH`
M````1`X0`D$.""P```!D`@``\(;__[8`````00X0A@)!#AB#`TD.P$`"HPH.
M&$$.$$$."$$+`````!0```"4`@``@(?__P4``````````````#P```"L`@``
M>(?__\T!````0@X0C0)%#AB,`T$.((8$20XH@P5'#M`@`ET*#BA!#B!!#AA"
M#A!"#@A!"P`````4````[`(```B)__\E```````````````L````!`,``"")
M___:`````$0.$(,"`D$*#@A+"P)4"@X(1`M&"@X(2@MA#@@````<````-`,`
M`-")___+`0```$0.0`-L`0H."$@+`````!P```!4`P``@(O__T@`````1`X0
M3PH."$4+;PX(````'````'0#``"PB___)`````!$#A!8"@X(1`L```````!$
M````E`,``,"+__\'`0```$(.$(X"0@X8C0-"#B",!$0.*(8%00XP@P9)#G`"
MDPH.,$$.*$$.($(.&$(.$$(."$$+``````!,````W`,``(B,__\E"@```$(.
M$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T\.P(,"`S<#"@XX00XP00XH
M0@X@0@X80@X00@X(1@L``#P````L!```:);___0#````0@X0C0)$#AB,`T$.
M((8$00XH@P5$#C`#7@(*#BA!#B!!#AA"#A!"#@A("P`````T````;`0``"B:
M__]P`````$$.$(8"1`X8@P-$#B`"5@H.&$$.$$$."$$+1`X81`X000X(````
M`!0```"D!```8)K__T``````1`X0=PX(`"0```"\!```V&+__QX"````00X0
M@P)$#C`#GP$*#A!##@A!"P`````4````Y`0``&":__\<```````````````D
M````_`0``&B:__^)`````%&,!88&7PY`1H,'CP*.`XT$`E(."```%````"0%
M``#0FO__`@``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````/__________``````````#__________P`````````````````````!
M``````````$``````````0````````"R`@````````$``````````0,`````
M```,`````````)@=0```````#0````````!H6T```````/7^_V\`````F`)`
M```````%`````````(`.0```````!@````````"@`T````````H`````````
MXP4````````+`````````!@`````````%0````````````````````,`````
M````Z,]@```````"`````````(`'````````%``````````'`````````!<`
M````````&!9````````'`````````-`50```````"`````````!(````````
M``D`````````&`````````#^__]O`````%`50```````____;P`````"````
M`````/#__V\`````9!1`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````##.8```````````
M`````````````````,8=0```````UAU```````#F'4```````/8=0```````
M!AY````````6'D```````"8>0```````-AY```````!&'D```````%8>0```
M````9AY```````!V'D```````(8>0```````EAY```````"F'D```````+8>
M0```````QAY```````#6'D```````.8>0```````]AY````````&'T``````
M`!8?0```````)A]````````V'T```````$8?0```````5A]```````!F'T``
M`````'8?0```````AA]```````"6'T```````*8?0```````MA]```````#&
M'T```````-8?0```````YA]```````#V'T````````8@0```````%B!`````
M```F($```````#8@0```````1B!```````!6($```````&8@0```````=B!`
M``````"&($```````)8@0```````IB!```````"V($```````,8@0```````
MUB!```````#F($```````/8@0```````!B%````````6(4```````"8A0```
M````-B%```````!&(4```````%8A0```````9B%```````!V(4```````(8A
M0```````EB%```````"F(4```````+8A0```````QB%```````#6(4``````
M`.8A0```````]B%````````&(D```````!8B0```````)B)````````V(D``
M`````$8B0```````5B)```````!F(D```````'8B0```````AB)```````"6
M(D```````*8B0```````MB)`````````````````````````````_____P``
M``#I6P```````"JZ0```````1T-#.B`H56)U;G1U+TQI;F%R;R`T+C8N,2TR
M=6)U;G1U,2D@-"XV+C$`1T-#.B`H56)U;G1U+TQI;F%R;R`T+C4N,RTQ=6)U
M;G1U,BD@-"XU+C,``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`
M+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`
M+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP
M;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE
M:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9V]T
M+G!L=``N9&%T80`N8G-S`"YC;VUM96YT````````````````````````````
M````````````````````````````````````````````````````````````
M```````+`````0````(`````````.`)````````X`@```````!P`````````
M```````````!````````````````````$P````<````"`````````%0"0```
M````5`(````````@````````````````````!````````````````````"$`
M```'`````@````````!T`D```````'0"````````)```````````````````
M``0````````````````````T````]O__;P(`````````F`)```````"8`@``
M``````0!````````!0`````````(````````````````````/@````L````"
M`````````*`#0```````H`,```````#@"@````````8````!````"```````
M```8`````````$8````#`````@````````"`#D```````(`.````````XP4`
M``````````````````$```````````````````!.````____;P(`````````
M9!1```````!D%````````.@`````````!0`````````"``````````(`````
M````6P```/[__V\"`````````%`50```````4!4```````"```````````8`
M```"````"````````````````````&H````$`````@````````#0%4``````
M`-`5````````2``````````%``````````@`````````&`````````!T````
M!`````(`````````&!9````````8%@```````(`'````````!0````P````(
M`````````!@`````````?@````$````&`````````)@=0```````F!T`````
M```8````````````````````!````````````````````'D````!````!@``
M``````"P'4```````+`=````````$`4``````````````````!``````````
M$`````````"$`````0````8`````````P")```````#`(@```````*@X````
M```````````````0````````````````````B@````$````&`````````&A;
M0```````:%L````````.````````````````````!```````````````````
M`)`````!`````@````````"`6T```````(!;````````L5X`````````````
M`````"````````````````````"8`````0````(`````````-+I````````T
MN@```````/0````````````````````$````````````````````I@````$`
M```"`````````"B[0```````*+L````````\!0``````````````````"```
M`````````````````+`````!`````P`````````(SF````````C.````````
M$`````````````````````@```````````````````"W`````0````,`````
M````&,Y@```````8S@```````!`````````````````````(````````````
M````````O@````$````#`````````"C.8```````*,X````````(````````
M````````````"````````````````````,,````&`````P`````````PSF``
M`````##.````````L`$````````&``````````@`````````$`````````#,
M`````0````,`````````X,]@``````#@SP````````@`````````````````
M```(``````````@`````````T0````$````#`````````.C/8```````Z,\`
M``````"8`@``````````````````"``````````(`````````-H````!````
M`P````````"`TF```````(#2````````*`````````````````````@`````
M``````````````#@````"`````,`````````P-)@``````"HT@```````(`0
M```````````````````@````````````````````Y0````$````P````````
M````````````J-(```````!4`````````````````````0`````````!````
M``````$````#`````````````````````````/S2````````[@``````````
7``````````$`````````````````````
